<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../about.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="48"/>
        <source>Lightweight file manager</source>
        <translation>Легковесный диспетчер файлов</translation>
    </message>
    <message>
        <location filename="../about.ui" line="58"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="78"/>
        <source>Authors</source>
        <translation>Авторы</translation>
    </message>
    <message>
        <location filename="../about.ui" line="87"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>Программирование:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="100"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../about.ui" line="109"/>
        <source>PCMan File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>Файловый менеджер PCMan

Авторское право (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

Эта программа является свободным программным обеспечением;
вы можете распространять и/или модифицировать ее согласно
условиям стандартной общественной лицензии GNU, опубликованной
Фондом свободного ПО; либо версии 2 лицензии, либо
(по вашему выбору) любой более поздней версии.

Эта программа распространяется в надежде что она будет полезной,
но БЕЗ КАКИХ-ЛИБО ГАРАНТИЙ; даже без подразумеваемых гарантий
КОММЕРЧЕСКОЙ ЦЕННОСТИ или ПРИГОДНОСТИ ДЛЯ КОНКРЕТНОЙ ЦЕЛИ.
Смотрите Стандартную Общественную Лицензию GNU для большего
количества деталей.

Вы должны были получить копию Стандартной Общественной Лицензии GNU
вместе с этой программой; если лицензии не было, напишите в Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Бостон, MA  02110-1301, США.</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../autorun.ui" line="14"/>
        <source>Removable medium is inserted</source>
        <translation>Вставлен съёмный носитель</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="33"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;Вставлен съёмный носитель&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="40"/>
        <source>Type of medium:</source>
        <translation>Тип носителя:</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="47"/>
        <source>Detecting...</source>
        <translation>Обнаружение...</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="56"/>
        <source>Please select the action you want to perform:</source>
        <translation>Выберите действие, которое хотите совершить:</translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../desktop-folder.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="23"/>
        <source>Desktop</source>
        <translation>Рабочий стол</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="29"/>
        <source>Desktop folder:</source>
        <translation>Папка рабочего стола:</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="36"/>
        <source>Image file</source>
        <translation>Файл изображения</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="42"/>
        <source>Folder path</source>
        <translation>Путь к папке</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="49"/>
        <source>&amp;Browse</source>
        <translation>&amp;Обзор</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktop-preferences.ui" line="14"/>
        <source>Desktop Preferences</source>
        <translation>Настройки рабочего стола</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="24"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="30"/>
        <source>Background</source>
        <translation>Фон</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="52"/>
        <source>Wallpaper mode:</source>
        <translation>Режим обоев:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="65"/>
        <source>Wallpaper image file:</source>
        <translation>Файл изображения обоев:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="85"/>
        <source>Select background color:</source>
        <translation>Выбрать цвет фона:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="94"/>
        <source>Image file</source>
        <translation>Файл изображения</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="100"/>
        <source>Image file path</source>
        <translation>Путь к файлу изображения</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="107"/>
        <source>&amp;Browse</source>
        <translation>&amp;Обзор</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="119"/>
        <source>Label Text</source>
        <translation>Текст ярлыков</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="157"/>
        <source>Select  text color:</source>
        <translation>Выбрать цвет текста:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="170"/>
        <source>Select shadow color:</source>
        <translation>Выбрать цвет тени:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="183"/>
        <source>Select font:</source>
        <translation>Выбрать шрифт:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="226"/>
        <source>Window Manager</source>
        <translation>Оконный менеджер</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="220"/>
        <source>Advanced</source>
        <translation>Расширенные</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="232"/>
        <source>Show menus provided by window managers when desktop is clicked</source>
        <translation>Показывать меню, предоставляемые оконными менеджерами, по клику на рабочий стол</translation>
    </message>
</context>
<context>
    <name>FindFilesDialog</name>
    <message>
        <location filename="../file-search.ui" line="14"/>
        <source>Find Files</source>
        <translation>Найти файлы</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="24"/>
        <source>Name/Location</source>
        <translation>Имя/расположение</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="30"/>
        <source>File name patterns</source>
        <translation>Шаблоны имён файлов</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="36"/>
        <source>Pattern:</source>
        <translation>Шаблон:</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="46"/>
        <location filename="../file-search.ui" line="221"/>
        <source>Case insensitive</source>
        <translation>Нечувствительный к регистру</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="53"/>
        <location filename="../file-search.ui" line="228"/>
        <source>Use regular expression</source>
        <translation>Использовать регулярные выражения</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="63"/>
        <source>Places to search</source>
        <translation>Места поиска</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="76"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="88"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="117"/>
        <source>Search in sub directories</source>
        <translation>Искать в подпапках</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="124"/>
        <source>Search hidden files</source>
        <translation>Искать скрытые файлы</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="135"/>
        <location filename="../file-search.ui" line="141"/>
        <source>File Type</source>
        <translation>Тип файла</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="147"/>
        <source>Only search for files of following types:</source>
        <translation>Искать только следующие типы файлов:</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="154"/>
        <source>Text files</source>
        <translation>Текстовые файлы</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="161"/>
        <source>Image files</source>
        <translation>Файлы изображений</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="168"/>
        <source>Audio files</source>
        <translation>Аудиофайлы</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="175"/>
        <source>Video files</source>
        <translation>Видеофайлы</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="182"/>
        <source>Documents</source>
        <translation>Документы</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="206"/>
        <source>Content</source>
        <translation>Содержание</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="212"/>
        <source>File contains</source>
        <translation>Файл содержит</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="252"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="258"/>
        <source>File Size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="264"/>
        <source>Bigger than:</source>
        <translation>Больше, чем:</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="289"/>
        <source>Smaller than:</source>
        <translation>Меньше, чем:</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="317"/>
        <source>Last Modified Time</source>
        <translation>Время последнего изменения</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="323"/>
        <source>Earlier than:</source>
        <translation>Раньше, чем:</translation>
    </message>
    <message>
        <location filename="../file-search.ui" line="340"/>
        <source>Later than:</source>
        <translation>Позже, чем:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main-win.ui" line="14"/>
        <source>File Manager</source>
        <translation>Диспетчер файлов</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="692"/>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="705"/>
        <source>Ctrl+Alt+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="721"/>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="91"/>
        <source>Filter by string...</source>
        <translation>Фильтровать по строке...</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="115"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="119"/>
        <source>C&amp;reate New</source>
        <translation>&amp;Создать</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="137"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="143"/>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="147"/>
        <source>&amp;Sorting</source>
        <translation>&amp;Сортировка</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="174"/>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="189"/>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Закладки</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="196"/>
        <source>&amp;Go</source>
        <translation>&amp;Перейти</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="211"/>
        <source>&amp;Tool</source>
        <translation>&amp;Инструмент</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="228"/>
        <source>Main Toolbar</source>
        <translation>Главная панель инструментов</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="256"/>
        <source>Go &amp;Up</source>
        <translation>Перейти вв&amp;ерх</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="259"/>
        <source>Go Up</source>
        <translation>Перейти вверх</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="262"/>
        <source>Alt+Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="272"/>
        <source>&amp;Home</source>
        <translation>&amp;Домой</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="275"/>
        <source>Alt+Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="285"/>
        <source>&amp;Reload</source>
        <translation>&amp;Обновить</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="288"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="298"/>
        <source>Go</source>
        <translation>Перейти</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="308"/>
        <source>Quit</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="318"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="328"/>
        <source>&amp;New Window</source>
        <translation>Новое &amp;окно</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="331"/>
        <source>New Window</source>
        <translation>Новое окно</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="334"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="342"/>
        <source>Show &amp;Hidden</source>
        <translation>Показать &amp;скрытые</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="345"/>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="355"/>
        <source>&amp;Computer</source>
        <translation>&amp;Компьютер</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="365"/>
        <source>&amp;Trash</source>
        <translation>&amp;Корзина</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="370"/>
        <source>&amp;Network</source>
        <translation>&amp;Сеть</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="380"/>
        <source>&amp;Desktop</source>
        <translation>&amp;Рабочий стол</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="390"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>&amp;Добавить в закладки</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="395"/>
        <source>&amp;Applications</source>
        <translation>&amp;Приложения</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="400"/>
        <source>Reload</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="408"/>
        <source>&amp;Icon View</source>
        <translation>Просмотр &amp;значками</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="416"/>
        <source>&amp;Compact View</source>
        <translation>&amp;Компактный просмотр</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="424"/>
        <source>&amp;Detailed List</source>
        <translation>Просмотр &amp;подробным списком</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="432"/>
        <source>&amp;Thumbnail View</source>
        <translation>Просмотр &amp;эскизами</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="442"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Вырезать</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="445"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="455"/>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="458"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="468"/>
        <source>&amp;Paste</source>
        <translation>&amp;Вставить</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="471"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="476"/>
        <source>Select &amp;All</source>
        <translation>Выделить &amp;всё</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="479"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="484"/>
        <source>Pr&amp;eferences</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="492"/>
        <source>&amp;Ascending</source>
        <translation>По &amp;возрастанию</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="500"/>
        <source>&amp;Descending</source>
        <translation>По &amp;убыванию</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="508"/>
        <source>&amp;By File Name</source>
        <translation>&amp;По имени файла</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="516"/>
        <source>By &amp;Modification Time</source>
        <translation>По времени &amp;изменения</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="524"/>
        <source>By File &amp;Type</source>
        <translation>По &amp;типу файла</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="532"/>
        <source>By &amp;Owner</source>
        <translation>По &amp;владельцу</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="540"/>
        <source>&amp;Folder First</source>
        <translation>Сначала &amp;папки</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="643"/>
        <source>&amp;Case Sensitive</source>
        <translation>&amp;Чувствительная к регистру</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="651"/>
        <source>By File &amp;Size</source>
        <translation>По &amp;размеру файла</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="656"/>
        <source>&amp;Close Window</source>
        <translation>&amp;Закрыть окно</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="689"/>
        <source>&amp;Folder</source>
        <translation>&amp;Папка</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="702"/>
        <source>&amp;Blank File</source>
        <translation>&amp;Пустой файл</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="710"/>
        <source>&amp;Find Files</source>
        <translation>&amp;Найти файлы</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="713"/>
        <source>F3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="729"/>
        <source>Close &amp;left tabs</source>
        <translation>Закрыть вкладки с&amp;лева</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="737"/>
        <source>Close &amp;right tabs</source>
        <translation>Закрыть вкладки с&amp;права</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="742"/>
        <source>Close &amp;other tabs</source>
        <translation>Закрыть &amp;остальные вкладки</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="550"/>
        <source>New &amp;Tab</source>
        <translation>Новая &amp;вкладка</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="553"/>
        <source>New Tab</source>
        <translation>Новая вкладка</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="556"/>
        <source>Ctrl+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="566"/>
        <source>Go &amp;Back</source>
        <translation>Перейти &amp;назад</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="569"/>
        <source>Go Back</source>
        <translation>Перейти назад</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="572"/>
        <source>Alt+Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="582"/>
        <source>Go &amp;Forward</source>
        <translation>Перейти &amp;вперёд</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="585"/>
        <source>Go Forward</source>
        <translation>Перейти вперёд</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="588"/>
        <source>Alt+Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="593"/>
        <source>&amp;Invert Selection</source>
        <translation>&amp;Инвертировать выделение</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="603"/>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="606"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="611"/>
        <source>&amp;Rename</source>
        <translation>&amp;Переименовать</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="614"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="619"/>
        <source>C&amp;lose Tab</source>
        <translation>&amp;Закрыть вкладку</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="622"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="627"/>
        <source>File &amp;Properties</source>
        <translation>Свойства &amp;файла</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="630"/>
        <source>Alt+Return</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="635"/>
        <source>&amp;Folder Properties</source>
        <translation>Свойства &amp;папки</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="661"/>
        <source>Edit Bookmarks</source>
        <translation>Изменить закладки</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="666"/>
        <source>Open &amp;Terminal</source>
        <translation>Открыть &amp;терминал</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="669"/>
        <source>F4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="674"/>
        <source>Open as &amp;Root</source>
        <translation>Открыть от имени &amp;суперпользователя</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="679"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>&amp;Изменить закладки</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../application.cpp" line="165"/>
        <source>Name of configuration profile</source>
        <translation>Имя профиля конфигурации</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="165"/>
        <source>PROFILE</source>
        <translation>ПРОФИЛЬ</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="168"/>
        <source>Run PCManFM as a daemon</source>
        <translation>Запустить PCManFM как демон</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="171"/>
        <source>Quit PCManFM</source>
        <translation>Выйти из PCManFM</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="174"/>
        <source>Launch desktop manager</source>
        <translation>Запустить менеджер рабочего стола</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="177"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>Отключить менеджер рабочего стола, если он запущен</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="180"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>Открыть диалог настроек рабочего стола на странице с указанным именем</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="180"/>
        <location filename="../application.cpp" line="196"/>
        <source>NAME</source>
        <translation>ИМЯ</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="189"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>Выбрать обои рабочего стола из ФАЙЛА изображения</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="189"/>
        <source>FILE</source>
        <translation>ФАЙЛ</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="193"/>
        <source>Set mode of desktop wallpaper. MODE=(color|stretch|fit|center|tile)</source>
        <translation>Выбрать режим обоев рабочего стола. РЕЖИМ=(color|stretch|fit|center|tile)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="193"/>
        <source>MODE</source>
        <translation>РЕЖИМ</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation>Открыть диалог настроек на странице с указанным именем</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="183"/>
        <source>Open new window</source>
        <translation>Открыть новое окно</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>Open Find Files utility</source>
        <translation>Открыть утилиту поиска файлов</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="199"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[ФАЙЛ1, ФАЙЛ2,...]</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="199"/>
        <source>Files or directories to open</source>
        <translation>Файлы или папки для открытия</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="503"/>
        <location filename="../application.cpp" line="510"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="510"/>
        <source>Terminal emulator is not set.</source>
        <translation>Эмулятор терминала не указан.</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../autorundialog.cpp" line="43"/>
        <source>Open in file manager</source>
        <translation>Открыть в диспетчере файлов</translation>
    </message>
    <message>
        <location filename="../autorundialog.cpp" line="133"/>
        <source>Removable Disk</source>
        <translation>Съёмный диск</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="50"/>
        <source>Fill with background color only</source>
        <translation>Заполнить только цветом фона</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="51"/>
        <source>Stretch to fill the entire screen</source>
        <translation>Растянуть по всему экрану</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="52"/>
        <source>Stretch to fit the screen</source>
        <translation>Растянуть по размеру экрана</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="53"/>
        <source>Center on the screen</source>
        <translation>По центру экрана</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="54"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>Плиточное заполнение всего экрана изображением</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="157"/>
        <source>Image Files</source>
        <translation>Файлы изображений</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../desktopwindow.cpp" line="366"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>&amp;Прикрепить к текущему положению</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="388"/>
        <source>Desktop Preferences</source>
        <translation>Настройки рабочего стола</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Стереть текст (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>Version: %1</source>
        <translation>Версия: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="958"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Переместить в корзину</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="958"/>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1020"/>
        <location filename="../mainwindow.cpp" line="1031"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1031"/>
        <source>Switch user command is not set.</source>
        <translation>Команда переключения пользователя не задана.</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="190"/>
        <source>Icon View</source>
        <translation>Просмотр значками</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="191"/>
        <source>Compact Icon View</source>
        <translation>Просмотр компактными значками</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="192"/>
        <source>Thumbnail View</source>
        <translation>Просмотр эскизами</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="193"/>
        <source>Detailed List View</source>
        <translation>Просмотр подробным списком</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../tabpage.cpp" line="255"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="268"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>Свободное место: %1 (всего: %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="283"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n объект</numerusform>
            <numerusform>%n объекта</numerusform>
            <numerusform>%n объектов</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="285"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform> (%n скрыт)</numerusform>
            <numerusform> (%n скрыто)</numerusform>
            <numerusform> (%n скрыто)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="436"/>
        <source>%1 item(s) selected</source>
        <translation>%1 объекта(ов) выделено</translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../view.cpp" line="103"/>
        <source>Open in New T&amp;ab</source>
        <translation>Открыть в новой &amp;вкладке</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="107"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Открыть в новом &amp;окне</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="114"/>
        <source>Open in Termina&amp;l</source>
        <translation>Открыть в &amp;терминале</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="45"/>
        <source>User Interface</source>
        <translation>Интерфейс пользователя</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="35"/>
        <source>Behavior</source>
        <translation>Поведение</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="50"/>
        <location filename="../preferences.ui" line="524"/>
        <source>Thumbnail</source>
        <translation>Эскизы</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="55"/>
        <source>Volume</source>
        <translation>Том</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="60"/>
        <source>Advanced</source>
        <translation>Расширенные</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="220"/>
        <source>Icons</source>
        <translation>Значки</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="249"/>
        <source>Size of big icons:</source>
        <translation>Размер больших значков:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="259"/>
        <source>Size of small icons:</source>
        <translation>Размер маленьких значков:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="269"/>
        <source>Size of thumbnails:</source>
        <translation>Размер эскизов:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="279"/>
        <source>Size of side pane icons:</source>
        <translation>Размер значков боковой панели:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="232"/>
        <source>Icon theme:</source>
        <translation>Тема значков:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="352"/>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="361"/>
        <source>Always show the tab bar</source>
        <translation>Всегда показывать панель вкладок</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="368"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>Показывать кнопку «Закрыть» на вкладках</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="375"/>
        <source>Remember the size of the last closed window</source>
        <translation>Запоминать размер последнего закрытого окна</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="382"/>
        <source>Default width of new windows:</source>
        <translation>Ширина новых окон по умолчанию:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="389"/>
        <source>Default height of new windows:</source>
        <translation>Высота новых окон по умолчанию:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="81"/>
        <source>Browsing</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="90"/>
        <source>Open files with single click</source>
        <translation>Открывать файлы по одиночному щелчку мыши</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="100"/>
        <source>Delay of auto-selection in single click mode (0 to disable)</source>
        <translation>Задержка автовыделения в режиме одиночного щелчка (0 для отключения)</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="107"/>
        <source>Default view mode:</source>
        <translation>Режим просмотра по умолчанию:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="120"/>
        <source> sec</source>
        <translation> сек</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="159"/>
        <source>File Operations</source>
        <translation>Операции с файлами</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="165"/>
        <source>Confirm before deleting files</source>
        <translation>Подтверждение перед удалением файлов</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="172"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>Перемещать удалённые файлы в «корзину» вместо удаления их с диска.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="554"/>
        <source>Show thumbnails of files</source>
        <translation>Показывать эскизы файлов</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="547"/>
        <source>Only show thumbnails for local files</source>
        <translation>Показывать эскизы только для локальных файлов</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="40"/>
        <source>Display</source>
        <translation>Вид</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="130"/>
        <source>Bookmarks:</source>
        <translation>Закладки:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="138"/>
        <source>Open in current tab</source>
        <translation>Открывать в текущей вкладке</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="143"/>
        <source>Open in new tab</source>
        <translation>Открывать в новой вкладке</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="148"/>
        <source>Open in new window</source>
        <translation>Открывать в новом окне</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="179"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation>Удалять файлы на съёмных носителях вместо создания «корзины»</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="186"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation>Подтверждение перед перемещением файлов в «корзину»</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="193"/>
        <source>Don&apos;t ask options on launch executable file</source>
        <translation>Не предлагать варианты запуска исполняемых файлов</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="292"/>
        <source>User interface</source>
        <translation>Интерфейс пользователя</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="305"/>
        <source>Treat backup files as hidden</source>
        <translation>Рассматривать резервные файлы как скрытые</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="315"/>
        <source>Always show full file names</source>
        <translation>Всегда показывать полные имена файлов</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="325"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>Показывать значки скрытых файлов затенёнными</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="413"/>
        <source>Show in places</source>
        <translation>Показвать в «Местах»</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="420"/>
        <source>Home</source>
        <translation>Дом</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="433"/>
        <source>Desktop</source>
        <translation>Рабочий стол</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="446"/>
        <source>Trash can</source>
        <translation>Корзина</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="459"/>
        <source>Computer</source>
        <translation>Компьютер</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="472"/>
        <source>Applications</source>
        <translation>Приложения</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="480"/>
        <source>Devices</source>
        <translation>Устройства</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="488"/>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="530"/>
        <source>Do not generate thumbnails for image files exceeding this size:</source>
        <translation>Не создавать эскизы для файлов изображений больших чем:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="537"/>
        <source> KB</source>
        <translation> КБ</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="581"/>
        <source>Auto Mount</source>
        <translation>Автоподключение</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="587"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>Подключать съёмные тома автоматически при запуске программы</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="594"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>Подключать съёмные тома автоматически при их вставлении</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="601"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>Показывать доступные варианты для съёмных устройств при их вставлении</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="611"/>
        <source>When removable medium unmounted:</source>
        <translation>При отключении съёмного устройства:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="617"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation>Закрыть &amp;вкладку, отображающую содержимое съёмного носителя</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="624"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation>Изме&amp;нить папку во вкладке на домашнюю</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="667"/>
        <source>Switch &amp;user command:</source>
        <translation>Команда смены &amp;пользователя:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="691"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>Ин&amp;теграция с архиваторами:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="714"/>
        <source>Templates</source>
        <translation>Шаблоны</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="720"/>
        <source>Show only user defined templates in menu</source>
        <translation>Показывать в меню только шаблоны, определённые пользователем</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="727"/>
        <source>Show only one template for each MIME type</source>
        <translation>Показывать только один шаблон для каждого типа MIME</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="734"/>
        <source>Run default application after creation from template</source>
        <translation>Запускать приложение по умолчанию после создания из шаблона</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="651"/>
        <source>Programs</source>
        <translation>Программы</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="660"/>
        <source>Terminal emulator:</source>
        <translation>Эмулятор терминала:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="680"/>
        <source>Examples: &quot;xterm -e %s&quot; for terminal or &quot;gksu %s&quot; for switching user.
%s = the command line you want to execute with terminal or su.</source>
        <translation>Примеры: &quot;xterm -e %s&quot; для терминала или &quot;gksu %s&quot; для переключения пользователя.
%s = командная строка,которую вы хотите выполнить с терминалом или su.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="298"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>Использовать десятичные префиксы СИ вместо двоичных префиксов IEC</translation>
    </message>
</context>
</TS>
